SortingMembers class
Annotation for sorting members.
- Annotations
-
- @Target.new({TargetKind.classType, TargetKind.mixinType, TargetKind.extensionType, TargetKind.extension, TargetKind.enumType})
Constructors
-
SortingMembers(Set<
SortDeclaration> declarations, {int? linesBetweenSameSortMembers, int? linesAroundSortedMembers, int? linesAroundUnsortedMembers, bool alphabetizeSortedMembers = false, bool alphabetizeUnsortedMembers = false}) -
Annotation for sorting members.
const
Properties
- alphabetizeSortedMembers → bool
-
Whether to alphabetize sorted members.
final
- alphabetizeUnsortedMembers → bool
-
Whether to alphabetize members not matched by any sort declaration.
final
-
declarations
→ Set<
SortDeclaration> -
The sort declarations.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- linesAroundSortedMembers → int?
-
The number of lines to insert around sorted members.
final
- linesAroundUnsortedMembers → int?
-
The number of lines to insert around unsorted members.
final
- linesBetweenSameSortMembers → int?
-
The number of lines to insert between members of the same sort type.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited